@@ -1,3 +1,11 @@
+from foundry.core.graphics_page.GraphicsPage import GraphicsPage
+from foundry.core.graphics_set.GraphicsSet import GraphicsSet
+from foundry.core.palette import COLORS_PER_PALETTE
+from foundry.core.palette.Palette import MutablePalette
+from foundry.core.palette.PaletteGroup import (
+    MutablePaletteGroup,
+    MutablePaletteGroupProtocol,
+)
 from foundry.core.player_animations import (
     PLAYER_FRAME_PAGE_OFFSET,
     PLAYER_FRAME_START,
@@ -11,22 +19,15 @@ from foundry.core.player_animations import (
 from foundry.core.player_animations.PlayerAnimation import PlayerAnimation
 from foundry.core.player_animations.PlayerAnimationData import PlayerAnimationData
 from foundry.game.File import ROM
-from foundry.game.gfx.GraphicsSet import GraphicalPage, GraphicsSet
-from foundry.game.gfx.Palette import (
-    COLORS_PER_PALETTE,
-    Palette,
-    PaletteGroup,
-    PaletteGroupProtocol,
-)
 
 
 def load_animations_graphic_set(animation: PlayerAnimation, power_up: int, offsets: list[int]) -> GraphicsSet:
     return GraphicsSet(
         (
-            GraphicalPage(animation.offset + offsets[power_up]),
-            GraphicalPage(animation.offset + offsets[power_up]),
-            GraphicalPage(animation.offset + offsets[power_up]),
-            GraphicalPage(animation.offset + offsets[power_up]),
+            GraphicsPage(animation.offset + offsets[power_up]),
+            GraphicsPage(animation.offset + offsets[power_up]),
+            GraphicsPage(animation.offset + offsets[power_up]),
+            GraphicsPage(animation.offset + offsets[power_up]),
         )
     )
 
@@ -44,7 +45,7 @@ def get_animations_palette_index(is_mario: bool, power_up: int) -> int:
 
 def load_player_animation(
     animation: PlayerAnimation,
-    palette_group: PaletteGroupProtocol,
+    palette_group: MutablePaletteGroupProtocol,
     is_mario: bool,
     power_up: int,
     offsets: list[int],
@@ -61,7 +62,7 @@ def load_player_animation(
 
 def load_player_animation_data(
     animations: list[PlayerAnimation],
-    palette_group: PaletteGroupProtocol,
+    palette_group: MutablePaletteGroupProtocol,
     is_mario: bool,
     power_up: int,
     offsets: list[int],
@@ -72,10 +73,10 @@ def load_player_animation_data(
     return animation_data
 
 
-def load_power_up_palettes() -> PaletteGroupProtocol:
-    return PaletteGroup(
+def load_power_up_palettes() -> MutablePaletteGroupProtocol:
+    return MutablePaletteGroup(
         [
-            Palette.from_rom(PLAYER_POWER_UPS_PALETTES + address * COLORS_PER_PALETTE)
+            MutablePalette.from_rom(PLAYER_POWER_UPS_PALETTES + address * COLORS_PER_PALETTE)
             for address in range(PLAYER_POWER_UPS_PALETTE_COUNT)
         ]
     )
