@@ -3,17 +3,18 @@ from functools import lru_cache
 from PySide6.QtCore import QPoint
 from PySide6.QtGui import QColor, QImage, QPainter, Qt
 
+from foundry.core.graphics_set.GraphicsSet import GraphicsSetProtocol
+from foundry.core.palette import NESPalette
+from foundry.core.palette.PaletteGroup import MutablePaletteGroupProtocol
 from foundry.game.File import ROM
 from foundry.game.gfx.drawable import MASK_COLOR, apply_selection_overlay
 from foundry.game.gfx.drawable.Tile import Tile
-from foundry.game.gfx.GraphicsSet import GraphicsSetProtocol
-from foundry.game.gfx.Palette import NESPalette, PaletteGroupProtocol
 
 
 @lru_cache(2 ** 10)
 def get_sprite(
     index: int,
-    palette_group: PaletteGroupProtocol,
+    palette_group: MutablePaletteGroupProtocol,
     palette_index: int,
     graphics_set: GraphicsSetProtocol,
     horizontal_mirror: bool = False,
@@ -37,7 +38,7 @@ class Sprite:
     def __init__(
         self,
         index: int,
-        palette_group: PaletteGroupProtocol,
+        palette_group: MutablePaletteGroupProtocol,
         palette_index: int,
         graphics_set: GraphicsSetProtocol,
         horizontal_mirror: bool = False,
