@@ -2,9 +2,10 @@ from functools import lru_cache
 
 from PySide6.QtGui import QImage
 
+from foundry.core.graphics_set.GraphicsSet import GraphicsSetProtocol
+from foundry.core.palette import NESPalette
+from foundry.core.palette.PaletteGroup import MutablePaletteGroup
 from foundry.game.gfx.drawable import MASK_COLOR, bit_reverse
-from foundry.game.gfx.GraphicsSet import GraphicsSetProtocol
-from foundry.game.gfx.Palette import NESPalette, PaletteGroup
 
 PIXEL_OFFSET = 8  # both bits describing the color of a pixel are in separate 8 byte chunks at the same index
 
@@ -23,7 +24,7 @@ class Tile:
     def __init__(
         self,
         object_index: int,
-        palette_group: PaletteGroup,
+        palette_group: MutablePaletteGroup,
         palette_index: int,
         graphics_set: GraphicsSetProtocol,
         mirrored=False,
