@@ -1,13 +1,13 @@
 from typing import List, Optional, Union
 
-from foundry.game.gfx.GraphicsSet import GraphicsSet, GraphicsSetProtocol
+from foundry.core.graphics_set.GraphicsSet import GraphicsSet, GraphicsSetProtocol
+from foundry.core.palette.PaletteGroup import MutablePaletteGroup
 from foundry.game.gfx.objects.Jump import Jump
 from foundry.game.gfx.objects.LevelObject import (
     SCREEN_HEIGHT,
     SCREEN_WIDTH,
     LevelObject,
 )
-from foundry.game.gfx.Palette import PaletteGroup
 
 
 class LevelObjectFactory:
@@ -48,7 +48,7 @@ class LevelObjectFactory:
 
     def set_palette_group_index(self, palette_group_index: int):
         self.palette_group_index = palette_group_index
-        self.palette_group = PaletteGroup.from_tileset(self.object_set, self.palette_group_index)
+        self.palette_group = MutablePaletteGroup.from_tileset(self.object_set, self.palette_group_index)
 
     def from_data(self, data: bytearray, index: int):
         if Jump.is_jump(data):
