@@ -5,10 +5,12 @@ from PySide6.QtCore import QPoint, QRect
 from PySide6.QtGui import QBrush, QColor, QImage, QPainter, QPen, Qt
 
 from foundry import data_dir
+from foundry.core.graphics_set.GraphicsSet import GraphicsSet
+from foundry.core.palette import NESPalette
+from foundry.core.palette.PaletteGroup import MutablePaletteGroup
 from foundry.game.File import ROM
 from foundry.game.gfx.drawable import apply_selection_overlay
 from foundry.game.gfx.drawable.Block import Block
-from foundry.game.gfx.GraphicsSet import GraphicsSet
 from foundry.game.gfx.objects.EnemyItem import MASK_COLOR, EnemyObject
 from foundry.game.gfx.objects.LevelObject import (
     GROUND,
@@ -21,11 +23,10 @@ from foundry.game.gfx.objects.ObjectLike import (
     EXPANDS_HORIZ,
     EXPANDS_VERT,
 )
-from foundry.game.gfx.Palette import NESPalette, PaletteGroup
 from foundry.game.level.Level import Level
 from foundry.gui.AutoScrollDrawer import AutoScrollDrawer
 from foundry.gui.settings import SETTINGS
-from foundry.smb3parse.constants import OBJ_AUTOSCROLL
+from foundry.smb3parse.constants import OBJ_AUTOSCROLL, TILESET_BACKGROUND_BLOCKS
 from foundry.smb3parse.levels import LEVEL_MAX_LENGTH
 from foundry.smb3parse.objects.object_set import (
     CLOUDY_OBJECT_SET,
@@ -90,7 +91,7 @@ SPECIAL_BACKGROUND_OBJECTS = [
 
 
 def get_blocks(level: Level) -> list[Block]:
-    palette_group = PaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
+    palette_group = MutablePaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
     palette_group = tuple(tuple(c for c in pal) for pal in palette_group)
     graphics_set = GraphicsSet.from_tileset(level.header.graphic_set_index)
     tsa_data = ROM().get_tsa_data(level.object_set_number)
@@ -107,7 +108,7 @@ def _block_from_index(block_index: int, level: Level) -> Block:
     :return:
     """
 
-    palette_group = PaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
+    palette_group = MutablePaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
     graphics_set = GraphicsSet.from_tileset(level.header.graphic_set_index)
     tsa_data = ROM().get_tsa_data(level.object_set_number)
 
@@ -136,6 +137,8 @@ class LevelDrawer:
     def draw(self, painter: QPainter, level: Level):
         self._draw_background(painter, level)
 
+        self._draw_default_graphics(painter, level)
+
         if level.object_set_number == DESERT_OBJECT_SET:
             self._draw_desert_default_graphics(painter, level)
         elif level.object_set_number == DUNGEON_OBJECT_SET:
@@ -143,9 +146,6 @@ class LevelDrawer:
         elif level.object_set_number == ICE_OBJECT_SET:
             self._draw_ice_default_graphics(painter, level)
 
-        # painter.setPen(QPen(QColor(0x00, 0x00, 0x00, 0x80), width=1))
-        # painter.setBrush(Qt.NoBrush)
-
         self._draw_objects(painter, level)
 
         self._draw_overlays(painter, level)
@@ -170,10 +170,10 @@ class LevelDrawer:
 
         if level.object_set_number == CLOUDY_OBJECT_SET:
             bg_color = NESPalette[
-                PaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)[3][2]
+                MutablePaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)[3][2]
             ]
         else:
-            bg_color = PaletteGroup.from_tileset(
+            bg_color = MutablePaletteGroup.from_tileset(
                 level.object_set_number, level.header.object_palette_index
             ).background_color
 
@@ -222,14 +222,20 @@ class LevelDrawer:
         for x, y in product(range(level.width), range(level.height)):
             bg_block.draw(painter, x * self.block_length, y * self.block_length, self.block_length)
 
+    def _draw_default_graphics(self, painter: QPainter, level: Level):
+        bg_block = _block_from_index(TILESET_BACKGROUND_BLOCKS[level.object_set_number], level)
+
+        for x, y in product(range(level.width), range(level.height)):
+            bg_block.draw(painter, x * self.block_length, y * self.block_length, self.block_length)
+
     def _draw_objects(self, painter: QPainter, level: Level):
         bg_palette_group = tuple(
             tuple(c for c in pal)
-            for pal in PaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
+            for pal in MutablePaletteGroup.from_tileset(level.object_set_number, level.header.object_palette_index)
         )
         spr_palette_group = tuple(
             tuple(c for c in pal)
-            for pal in PaletteGroup.from_tileset(level.object_set_number, 8 + level.header.enemy_palette_index)
+            for pal in MutablePaletteGroup.from_tileset(level.object_set_number, 8 + level.header.enemy_palette_index)
         )
 
         blocks = get_blocks(level)
